@@ -48,11 +48,11 @@ class ExtTag(Tag):
 
     def process(self, file: File, context: Optional[str]) -> str:
         if context:
-            return str(Path(context).suffix).lstrip(".")
-        return str(file.relative_path.suffix).lstrip(".")
+            return str(Path(context).suffix)
+        return str(file.relative_path.suffix)
 
 
-class BasenameTag(Tag):
+class BaseTag(Tag):
     """Renders base file name without extension (suffix)
 
     If no context is provided, current file path is used to determine the base file name.
@@ -67,7 +67,7 @@ class BasenameTag(Tag):
         return file.relative_path.stem
 
 
-class DirnameTag(Tag):
+class DirTag(Tag):
     """Renders file parent directory path
 
     If no context is provided, current file path is used to determine the parent directory.
@@ -82,7 +82,7 @@ class DirnameTag(Tag):
         return file.relative_path.parent
 
 
-class FilenameTag(Tag):
+class NameTag(Tag):
     """Renders processed file name (basename with extension)"""
 
     require_context = None
