@@ -1,8 +1,8 @@
 import datetime
 import os.path
-from pathlib import Path
 from typing import Any, Optional
 
+from tempren.path_generator import File
 from tempren.template.tree_elements import Tag
 
 
@@ -11,16 +11,18 @@ class SizeTag(Tag):
 
     require_context = False
 
-    def process(self, path: Path, context: Optional[str]) -> int:
+    def process(self, file: File, context: Optional[str]) -> int:
         assert context is None
-        return os.path.getsize(path)
+        return os.path.getsize(file.absolute_path)
 
 
 class MTimeTag(Tag):
     """Returns file modification time (in ISO 8601 format)"""
 
-    def process(self, path: Path, context: Optional[str]) -> Any:
+    require_context = False
+
+    def process(self, file: File, context: Optional[str]) -> Any:
         assert context is None
-        mtime_seconds = os.path.getmtime(path)
+        mtime_seconds = os.path.getmtime(file.absolute_path)
         mtime = datetime.datetime.fromtimestamp(mtime_seconds)
         return mtime.isoformat()
